rnalysis.enrichment.RankedSet.non\_categorical\_enrichment
==========================================================

.. currentmodule:: rnalysis.enrichment

.. automethod:: RankedSet.non_categorical_enrichment